<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Perception.Automation.Core

Windows Runtime (WinRT) APIs for for the `Windows.Perception.Automation.Core` namespace.

This package provides the `winrt.windows.perception.automation.core` module.
